import Vue from 'vue'
import Router from 'vue-router'


Vue.use(Router)
/**
 * Note: 路由配置项
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    keepAlive: true              // 如果设置为true，则会被 <keep-alive> 缓存 (默认 false)
    title: 'title'               // 设置该路由在页面顶部的Title
    index: '1'                   // 设置该路由页面切换是否左右滑动及权重，如不设页面不滑动  PS：功能暂时未启用
    hidden: true                 // 如果设置为true，显示底部菜单，如不设或者false，不显示
  }
 */
export const constantRoutes = [
  {
    path: '/',
    redirect: '/index'
  },
  {
    path: '/index',
    name: 'index',
    meta: {
      title: '主页',
      keepAlive: true
    },
    component: (resolve) => require(['@/views/index'], resolve)
  },
  {
    path: '/login',
    name: 'login',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/login'], resolve)
  },
  {
    path: '/register',
    name: 'register',
    meta: {
      title: '注册页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register'], resolve)
  },
  {
    path: '/document',
    name: 'document',
    meta: {
      title: '文档',
    },
    component: (resolve) => require(['@/views/document'], resolve)
  },
  {
    path: '/workbench',
    name: 'workbench',
    meta: {
      title: '工作台'
    },
    component: (resolve) => require(['@/views/workbench'], resolve)
  },
  {
    path: '/addressBook',
    name: 'addressBook',
    meta: {
      title: '通讯录'
    },
    component: (resolve) => require(['@/views/addressBook'], resolve)
  },
  {
    path: '/mynsgk',
    name: 'mynsgk',
    meta: {
      title: '我的'
    },
    component: (resolve) => require(['@/views/mynsgk'], resolve)
  }
];


export default new Router({
  linkActiveClass: 'active',
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
